#
# spec file for package cobbler
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitelib: %define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?pyver: %define pyver %(%{__python} -c "import sys ; print sys.version[:3]" || echo 0)}

%if 0%{?suse_version}
%define www_path /srv/
%define apache_user wwwrun
%define apache_group www
%define apachedir apache2
%else
%define www_path %{_var}
%define apache_user apache
%define apache_group apache
%define apachedir httpd
%endif

%define _binaries_in_noarch_packages_terminate_build 0
%global debug_package %{nil}
Summary:        Boot server configurator
License:        GPL-2.0+
Group:          Applications/System
Name:           cobbler
AutoReq:        no
Version:        2.6.6
Release:        4.35
Source0:        cobbler-%{version}.tar.gz
Source1:        vendor-files.tar.bz2
Source2:        fence_ipmitool.sh
Patch2:         cobbler_web_config.diff
%if 0%{?suse_version}
Patch4:         grubby-compat.diff
%endif
Patch5:         koan_old_cobbler_compat.diff
Patch6:         looking_for_cobbler_order_changed.diff
Patch7:         catch_cheetah_exception.patch
Patch9:         fix-restart-paravirt-xen.dif
Patch10:        disable_not_relevant_checks_bnc_828453.patch
Patch11:        fix-powermanagement-status.dif
Patch13:        fix_sle_detection.patch
Patch14:        do_not_use_grubby_compat_when_grub2_is_in_use.diff
Patch16:        fix-koan-port-guessing.dif
# PATCH-FIX-SLE name-of-file.patch bnc#883487 dmacvicar@suse.de
Patch18:        cobbler-2.4.2-reprovision-rhel-on-suse-bnc883487.patch
Patch19:        fix-broken-tests.diff
Patch20:        fix_test_create_systems.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Url:            http://www.cobblerd.org/

BuildRequires:  git
BuildRequires:  python-cheetah
%if 0%{?suse_version}
BuildRequires:  apache2
BuildRequires:  atftp
BuildRequires:  distribution-release
BuildRequires:  fdupes
Requires:       apache2-mod_wsgi
Requires:       ipmitool
Requires:       python-PyYAML
%else
BuildRequires:  redhat-rpm-config
Requires:       PyYAML
Requires:       httpd
Requires:       mod_wsgi
%endif

Requires:       createrepo
Requires:       python >= 2.3
Requires:       python-cheetah
Requires:       python-netaddr
Requires:       python-simplejson
Requires:       python-urlgrabber
Requires:       rsync
%ifarch %ix86 x86_64
Requires:       syslinux
%endif
%ifarch s390x
Requires:       syslinux-x86_64
%endif
Requires:       tftp(server)

%if 0%{?fedora} >= 11 || 0%{?rhel} >= 6 || 0%{?suse_version}
Requires:       genisoimage
%else
Requires:       mkisofs
%endif

%if 0%{?fedora} >= 11 || 0%{?rhel} >= 6
Requires:       python(abi) >= %{pyver}
%endif

%if 0%{?fedora} >= 8
BuildRequires:  python-setuptools-devel
%else
BuildRequires:  python-setuptools
%endif

%if 0%{?fedora} >= 6 || 0%{?rhel} >= 5 || 0%{?suse_version}
Requires:       yum-utils
%endif

%if 0%{?fedora} >= 16
BuildRequires:  systemd-units
Requires(post): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%else
%if 0%{?suse_version}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%else
Requires(post):  /sbin/chkconfig
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service
%endif
%endif

%description

Cobbler is a network install server.  Cobbler supports PXE,
virtualized installs, and re-installing existing Linux machines.  The
last two modes use a helper tool, 'koan', that integrates with
cobbler.  There is also a web interface 'cobbler-web'.  Cobbler's
advanced features include importing distributions from DVDs and rsync
mirrors, kickstart templating, integrated yum mirroring, and built-in
DHCP/DNS Management.  Cobbler has a XMLRPC API for integration with
other applications.

%prep
%setup -q
%setup -a1
%if 0%{?suse_version}
%patch2
%endif
%if 0%{?suse_version}
%patch4
%endif
%patch5
%patch6
%patch7 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch13 -p1
%if 0%{?suse_version}
%patch14 -p1
%endif
%patch16 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1

mv vendor-files/cobbler.1.gz docs

%build
%{__python} setup.py build

%install
test "x$RPM_BUILD_ROOT" != "x" && rm -rf $RPM_BUILD_ROOT
%{__python} setup.py install --optimize=1 --root=$RPM_BUILD_ROOT $PREFIX
mkdir -p $RPM_BUILD_ROOT/etc/%{apachedir}/conf.d
mv config/cobbler.conf $RPM_BUILD_ROOT/etc/%{apachedir}/conf.d/

mkdir -p $RPM_BUILD_ROOT/var/spool/koan

%if 0%{?fedora} >= 9 || 0%{?rhel} > 5
mkdir -p $RPM_BUILD_ROOT/var/lib/tftpboot/images
%else
%if 0%{?suse_version}
mkdir -p $RPM_BUILD_ROOT/srv/tftpboot/images
%else
mkdir -p $RPM_BUILD_ROOT/tftpboot/images
%endif
%endif

rm -f $RPM_BUILD_ROOT/etc/cobbler/cobblerd

%if 0%{?suse_version}
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/SuSEfirewall2.d
mv vendor-files/cobbler_firewall_settings $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/cobbler
install -m 755 %{S:2} $RPM_BUILD_ROOT/usr/sbin/fence_ipmitool
ln -sf service $RPM_BUILD_ROOT/usr/sbin/rccobblerd
chmod 755 $RPM_BUILD_ROOT/usr/sbin/grubby-compat
cp -r tests/ $RPM_BUILD_ROOT/usr/share/cobbler/
%endif

%if 0%{?fedora} >= 16 || 0%{?suse_version}
rm -rf $RPM_BUILD_ROOT/etc/init.d
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
mv $RPM_BUILD_ROOT%{_sysconfdir}/cobbler/cobblerd.service $RPM_BUILD_ROOT%{_unitdir}
%endif

%if 0%{?suse_version}
%fdupes %{buildroot}/usr
%endif

%if 0%{?suse_version}
%pre
%service_add_pre cobblerd.service

%post
if [ $1 -eq 1 ] ; then 
    # Initial installation 
    %if 0%{?suse_version}
        %{fillup_and_insserv cobblerd}
        sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES proxy
        sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES proxy_http
        sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES proxy_connect
        sysconf_addword /etc/sysconfig/apache2 APACHE_MODULES wsgi
    %else
        /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    %endif
elif [ "$1" -ge "2" ]; then
    # backup config
    if [ -e /var/lib/cobbler/distros ]; then
        cp /var/lib/cobbler/distros*  /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/profiles* /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/systems*  /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/repos*    /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/networks* /var/lib/cobbler/backup 2>/dev/null
    fi
    if [ -e /var/lib/cobbler/config ]; then
        cp -a /var/lib/cobbler/config    /var/lib/cobbler/backup 2>/dev/null
    fi
    # upgrade older installs
    # move power and pxe-templates from /etc/cobbler, backup new templates to *.rpmnew
    for n in power pxe; do
      rm -f /etc/cobbler/$n*.rpmnew
      find /etc/cobbler -maxdepth 1 -name "$n*" -type f | while read f; do
        newf=/etc/cobbler/$n/`basename $f`
        [ -e $newf ] &&  mv $newf $newf.rpmnew
        mv $f $newf
      done
    done
    # upgrade older installs
    # copy kickstarts from /etc/cobbler to /var/lib/cobbler/kickstarts
    rm -f /etc/cobbler/*.ks.rpmnew
    find /etc/cobbler -maxdepth 1 -name "*.ks" -type f | while read f; do
      newf=/var/lib/cobbler/kickstarts/`basename $f`
      [ -e $newf ] &&  mv $newf $newf.rpmnew
      cp $f $newf
    done
    # remove mod_python from apache
    sysconf_addword -r /etc/sysconfig/apache2 APACHE_MODULES python >/dev/null 2>&1
%if ! 0%{?suse_version}
    /bin/systemctl try-restart cobblerd.service >/dev/null 2>&1 || :
%endif
fi
%if 0%{?suse_version}
%service_add_post cobblerd.service
%endif

%preun
%if 0%{?suse_version}
%service_del_preun cobblerd.service
%else
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable cobblerd.service > /dev/null 2>&1 || :
    /bin/systemctl stop cobblerd.service > /dev/null 2>&1 || :
fi
%endif

%postun
%if 0%{?suse_version}
%service_del_postun cobblerd.service
%else
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart cobblerd.service >/dev/null 2>&1 || :
fi
%endif

%if ! 0%{?suse_version}
%triggerun -- cobbler < 2.0.11-3
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply cobblerd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save cobblerd >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del cobblerd >/dev/null 2>&1 || :
/bin/systemctl try-restart cobblerd.service >/dev/null 2>&1 || :
%endif

%else

%post
if [ "$1" = "1" ];
then
    # This happens upon initial install. Upgrades will follow the next else
    /sbin/chkconfig --add cobblerd
elif [ "$1" -ge "2" ];
then
    # backup config
    if [ -e /var/lib/cobbler/distros ]; then
        cp /var/lib/cobbler/distros*  /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/profiles* /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/systems*  /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/repos*    /var/lib/cobbler/backup 2>/dev/null
        cp /var/lib/cobbler/networks* /var/lib/cobbler/backup 2>/dev/null
    fi
    if [ -e /var/lib/cobbler/config ]; then
        cp -a /var/lib/cobbler/config    /var/lib/cobbler/backup 2>/dev/null
    fi
    # upgrade older installs
    # move power and pxe-templates from /etc/cobbler, backup new templates to *.rpmnew
    for n in power pxe; do
      rm -f /etc/cobbler/$n*.rpmnew
      find /etc/cobbler -maxdepth 1 -name "$n*" -type f | while read f; do
        newf=/etc/cobbler/$n/`basename $f`
        [ -e $newf ] &&  mv $newf $newf.rpmnew
        mv $f $newf
      done
    done
    # upgrade older installs
    # copy kickstarts from /etc/cobbler to /var/lib/cobbler/kickstarts
    rm -f /etc/cobbler/*.ks.rpmnew
    find /etc/cobbler -maxdepth 1 -name "*.ks" -type f | while read f; do
      newf=/var/lib/cobbler/kickstarts/`basename $f`
      [ -e $newf ] &&  mv $newf $newf.rpmnew
      cp $f $newf
    done
    # reserialize and restart
    # FIXIT: ?????
    #/usr/bin/cobbler reserialize
    /sbin/service cobblerd condrestart
fi

%preun
if [ $1 = 0 ]; then
    /sbin/service cobblerd stop >/dev/null 2>&1 || :
    chkconfig --del cobblerd || :
fi

%postun
if [ "$1" -ge "1" ]; then
    /sbin/service cobblerd condrestart >/dev/null 2>&1 || :
    /sbin/service httpd condrestart >/dev/null 2>&1 || :
fi

%endif

%clean
test "x$RPM_BUILD_ROOT" != "x" && rm -rf $RPM_BUILD_ROOT

%files

%defattr(-,root,root,-)

%{_bindir}/cobbler
%{_bindir}/cobbler-ext-nodes
%{_bindir}/cobblerd
%{_sbindir}/tftpd.py*

%config(noreplace) %{_sysconfdir}/cobbler
%if 0%{?fedora} >= 16 || 0%{?suse_version} > 1230
%{_unitdir}/cobblerd.service
%else
/etc/init.d/cobblerd
%endif

%{python_sitelib}/cobbler

%config(noreplace) /var/lib/cobbler
%exclude /var/lib/cobbler/webui_sessions

/var/log/cobbler
/%{www_path}/www/cobbler

%{_mandir}/man1/cobbler.1.gz

%config(noreplace) /etc/%{apachedir}/conf.d/cobbler.conf

%if 0%{?fedora} >= 9 || 0%{?rhel} >= 5 || 0%{?suse_version}
%exclude %{python_sitelib}/cobbler/sub_process.py*
%endif
%if 0%{?fedora} >= 9 || 0%{?rhel} > 5 || 0%{?suse_version}
%{python_sitelib}/cobbler*.egg-info
%if 0%{?suse_version}
/srv/tftpboot/images
%else
/var/lib/tftpboot/images
%endif
%else
/tftpboot/images
%endif

%doc AUTHORS README COPYING
%if 0%{?suse_version}
%config /etc/sysconfig/SuSEfirewall2.d/cobbler
/usr/sbin/fence_ipmitool
/usr/sbin/rccobblerd
%endif

%package -n koan

Summary:        Helper tool that performs cobbler orders on remote machines
Group:          Applications/System
Requires:       python >= 2.0
Requires:       python-simplejson
Requires:       virt-install
%if 0%{?fedora} >= 11 || 0%{?rhel} >= 6
Requires:       python(abi) >= %{pyver}
%endif

%description -n koan

Koan stands for kickstart-over-a-network and allows for both
network installation of new virtualized guests and reinstallation
of an existing system.  For use with a boot-server configured with Cobbler

%files -n koan
%defattr(-,root,root,-)
%dir /var/spool/koan
%dir /var/lib/koan
%dir /var/lib/koan/config
%{_bindir}/koan
%{_bindir}/ovz-install
%{_bindir}/cobbler-register
%{python_sitelib}/koan
%if 0%{?suse_version}
%attr(0755,root,root) /usr/sbin/grubby-compat
%endif

%if 0%{?fedora} >= 9 || 0%{?rhel} >= 5 || 0%{?suse_version}
%exclude %{python_sitelib}/koan/sub_process.py*
%exclude %{python_sitelib}/koan/opt_parse.py*
%exclude %{python_sitelib}/koan/text_wrap.py*
%endif

%{_mandir}/man1/koan.1.gz
%{_mandir}/man1/cobbler-register.1.gz
%dir /var/log/koan
%doc AUTHORS COPYING README

%package -n cobbler-web

Summary:        Web interface for Cobbler
Group:          Applications/System
Requires:       cobbler
%if 0%{?fedora} >= 11 || 0%{?rhel} >= 6
Requires:       Django >= 1.1.2
Requires:       mod_ssl
Requires:       mod_wsgi
Requires:       python(abi) >= %{pyver}
%endif
%if 0%{?suse_version}
Requires:       apache2-mod_wsgi
Requires:       python-django
%endif

%description -n cobbler-web

Web interface for Cobbler that allows visiting
http://server/cobbler_web to configure the install server.

%post -n cobbler-web
# Change the SECRET_KEY option in the Django settings.py file
# required for security reasons, should be unique on all systems
RAND_SECRET=$(openssl rand -base64 40 | sed 's/\//\\\//g')
sed -i -e "s/SECRET_KEY = ''/SECRET_KEY = \'$RAND_SECRET\'/" /usr/share/cobbler/web/settings.py

%files -n cobbler-web
%defattr(-,root,root,-)
%doc AUTHORS COPYING README
%config(noreplace) /etc/%{apachedir}/conf.d/cobbler_web.conf
%defattr(-,%{apache_user},%{apache_group},-)
/usr/share/cobbler/web
%dir %attr(700,%{apache_user},root) /var/lib/cobbler/webui_sessions
/%{www_path}/www/cobbler_webui_content/
%if 0%{?suse_version}
%dir /usr/share/cobbler
%endif

%if 0%{?suse_version}
%package -n cobbler-tests

Summary:        Unit tests for Cobbler
Group:          Applications/System
Requires:       cobbler

%description -n cobbler-tests

Unit test files from the Cobbler project

%files -n cobbler-tests
%defattr(-,root,root,-)
/usr/share/cobbler/tests
%endif #suse_version

%changelog
* Thu Jan 15 2015 fcastelli@suse.com
- Added 'fix_test_create_systems.diff': fixes the "create_systens" unit test
* Tue Jan 13 2015 fcastelli@suse.com
- Fix runtime dependency: ensure the yaml module is available.
* Tue Jan 13 2015 fcastelli@suse.com
- Install the right cobblerd.service file
* Mon Jan 12 2015 fcastelli@suse.com
- Do not ship cobbler_web.conf inside of the cobbler package, get rid
  of part of our patches to setup.py,
* Fri Dec 19 2014 fcastelli@suse.com
- Added new patch required to fix the broken unit tests:
  * fix-broken-tests.diff
* Thu Dec 18 2014 fcastelli@suse.com
- Removed another no longer needed patch:
  * fix-textmode-for-SUSE.dif
* Thu Dec 18 2014 fcastelli@suse.com
- Update to latest stable version of cobbler (2.6.6)
- Removed no longer needed patches
  * bnc_877009.patch
  * cobbler-2.4.2-Fix-koan-s-get_insert_script.patch
  * fix-broken-tests.diff
  * fix-initscript.diff
  * suse_config.diff
- Fixed old patches to apply against the new code:
  * catch_cheetah_exception.patch
  * grubby-compat.diff
  * setup_py.diff
* Mon Dec 15 2014 fcastelli@suse.com
- Fix the broken unit tests
* Thu Dec 11 2014 mseidl@suse.de
- Created sub package for unit tests
* Tue Dec  9 2014 mc@suse.de
- use fdupes only on SUSE
* Mon Dec  8 2014 dmacvicar@suse.de
- Fix for re-installation of machines on SLE with static
  network configuration (bnc#883487)
- Added patches:
  * cobbler-2.4.2-Fix-koan-s-get_insert_script.patch
  * cobbler-2.4.2-reprovision-rhel-on-suse-bnc883487.patch
* Thu Nov 27 2014 mc@suse.de
- fix port guessing in koan (bsc#855389)
  * fix-koan-port-guessing.dif
- add "copy-default" option to grubby-compat (bsc#855389)
- handle elilo in SUSE (bsc#855389)
* Wed Nov 26 2014 mc@suse.de
- fix wrong option "text" in SUSE environment (bsc#901058)
  * fix-textmode-for-SUSE.dif
* Thu Sep  4 2014 fcastelli@suse.com
- Added do_not_use_grubby_compat_when_grub2_is_in_use.diff: prevents
  usage of grubby-compat when grub2 is active. Use grub2 features
  do modify the boot loader.
* Tue Sep  2 2014 fcastelli@suse.com
- Moved grubby-compat inside of the koan sub-package. The scrit was accidentally
  moved into the cobbler package.
* Fri Jul 25 2014 fcastelli@suse.com
- Added fix_sle_detection.patch: ensures SLE12 is properly detected.
* Fri Jul 25 2014 fcastelli@suse.com
- Did some cleanup of the spec file.
* Tue Jul 15 2014 fcastelli@suse.com
- Fix source of cobbler package inside of spec file (required by openSUSE:Factory)
* Tue Jul 15 2014 fcastelli@suse.com
- Added bnc_877009.patch, fixes CVE-2014-3225: cobbler: Local file inclusion (bnc#877009)
* Mon Jul 14 2014 fcastelli@suse.com
- Got rid of some of the rpmlint warnings.
- Fixed error inside of koan tool introduced by the 'grubby-compat.diff' patch.
* Fri Jul 11 2014 mseidl@suse.de
- Requires tfpt-server but atftp/tftpt packages provide tfpt(server)
- Added conditional requires for s390x and syslinux-x86_64
- Added patches:
  + catch_cheetah_exception.patch
  - forward cheetah exception as 500 SERVER ERROR (bnc#787879)
  + disable_not_relevant_checks_bnc_828453.patch
  + fence_ipmitool.sh
  - add fence_ipmitool script for power management
  + fix-powermanagement-status.dif
  - fix evaluation of power status calls
  + fix-restart-paravirt-xen.dif
  - fix XEN fullvirt installation
  + grubby-compat.diff
  + koan_old_cobbler_compat.diff
  - add new grubby-compat tool
  + looking_for_cobbler_order_changed.diff
  - fix cobbler checks on SUSE (bnc#828453)
  + setup_py.diff
  - update paths for suse apache
- Modified fix-initscript.diff -Failed to patch due to new line in newer version
- Removed patches:
  - suse_newver.patch - Upstreamed
  - users_patch.diff - Upstreamed
  - cheetah_template_autoescape.patch - No longer needed
* Fri Feb 14 2014 mc@suse.de
- update to version 2.4.2
  + Adding support for gPXE
  + Adding support for ESXi5
  + fix install=... kernel parameter when importing a SUSE distro
  + koan: Port xen creation to virt-install
  + koan: Port qcreate to virt-install
  + Port koan from virtinst to virt-install command (v2)
  + add qcow2 driver type
  + Adding ability to use https for API calls (cobbler CLI)
  + Use ip instead of ifconfig for network snippets
  + minor modifications to templar to show template rendering errors
  + bugfixes and refactoring
* Tue Aug 13 2013 kkaempf@suse.com
- Update to 2.4.0
  Major Features:
  - Dynamic Settings
  - Distro Signatures
  - Vastly improved support for Ubuntu, OpenSUSE and VMware ESXi (5.0 and 5.1)
  - Added in new templated scripting support (needs documentation)
  - New web interface improvements (tabs, etc.)
  - Added apt-specific fields for repositories to make mirroring them easier
  - Support for parameterized classes and defines in puppet using management classes
  Minor Features:
  - Added the bonded_bridge_slave interface type:
  - Improved template error reporting
  - Variables in fields are now evaluated through the templating engine
  - Added openvz as a virtualization type for koan
  - Added --virt-pxe-boot option for koan to force PXE booting of new systems
  - Added a per-interface gateway option, for systems that support it
  - Added support for new puppet command syntax
  - Exposed replication rsync options
  Major Bugfixes:
  - --available-as no longer copies all files.
  - Improved gPXE/iPXE support, including FreeBSD
  - Deleting objects now respects the --recursive option again
  Minor Bugfixes:
  - Too many to list
* Wed Aug  7 2013 ro@suse.de
- fix filelist to fix build on factory: rpm does not allow to
  mark a non-directory as dir anymore
* Wed Apr 10 2013 rbrownccb@opensuse.org
- use systemd for openSUSE 12.3 and later
- change release number to match upstream
- drop obsolete setup_py.diff
- add required apache modules for cobbler-web
- add suse_newver.patch to add support for SLES11 SP3,
  openSUSE 12.3 and openSUSE 13.1
* Tue Apr  9 2013 rbrownccb@opensuse.org
- update to 2.2.3
  + Multiple security fixes
  + CSRF support for the web GUI, which will now default to using
    https too.
  + Power management subsystem completely re-worked to prevent
    command-injection (CVE-2012-2395)
  + Support for bind in chroot'd environments
  + Koan now uses virt-install CLI instead of directly accessing
    the virtinst API
  + Various improvements for SuSE and autoyast, especially for
    PPC64-based systems.
  + BETA support for ESXi5 and gPXE
  + BETA support for using other template languages, like jinja2
- rebase patches
- drop obsolete manage_import_suse.py
- no longer requires mod_python
* Thu May  3 2012 ug@suse.de
- require syslinux only on x86 arch
* Thu Apr 19 2012 ug@suse.de
- moved the secret generation from RPM post-script to the
  init-script, to avoid that all appliances will still have the
  same key
* Tue Apr 17 2012 ug@suse.de
- create a secret during installation
* Tue Mar 27 2012 chris@computersalat.de
- update to 2.2.2
  * please see CHANGELOG for more info
- remove obsolete virt-auto-boot patch
- rebase patches
* Mon Feb 13 2012 ug@suse.de
- fixed return value of rccobblerd status
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Dec 22 2011 ug@suse.de
- fix install=... kernel option when you import a SUSE distro
* Wed Oct 26 2011 ug@suse.de
- virtual machines autostart on boot fixed
* Fri Oct  7 2011 ug@suse.de
- Import modules, which allowed easy integration of...
- Ubuntu and Debian support again!
- Better support for SuSE
- Support for FreeBSD
- Support for ESX 4+/ESXi
- Integration with the python TFTP server pytftpd
- "fetchable files" and "boot files" support for distros that need to
  get more files from the TFTP server
- Faster sync using link cache
- Support for EFI grub booting
- Support for bridged interfaces
- WSGI instead of mod_python for the web interface.
- Lots of Web UI improvements
- A lot more I'm sure I missed when going through the change log
- version 2.2.1
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Aug 31 2011 ug@suse.de
- LOCKFILE usage removed on openSUSE
  (bnc#714618)
* Fri Jun 10 2011 ug@suse.de
- fixed the handling of cheetah template code in
  AutoYaST XML files
  (thanks to Jörgen Maas for pointing me to the bug)
- fixed parameter list in build-ISO code
  (thanks to Jörgen Maas for the patch)
* Thu Apr  7 2011 ug@suse.de
- added a backported upstream patch for tainted file error
  message
* Thu Apr  7 2011 ug@suse.de
- fix hostname in install=...
* Thu Apr  7 2011 ug@suse.de
- fix init-script
* Thu Apr  7 2011 ug@suse.de
- fixed apache config typo
* Wed Apr  6 2011 ug@suse.de
- added SUSE breed to import-webui
* Wed Apr  6 2011 ug@suse.de
- build ISO for SUSE fixed
* Wed Apr  6 2011 ug@suse.de
- added patch for autoyast XML files and cobbler triggers
* Wed Apr  6 2011 ug@suse.de
- added patch to fix koan with SUSE dists
* Tue Apr  5 2011 ug@suse.de
- fixed tftp-root path on SUSE
* Tue Apr  5 2011 ug@suse.de
- added support for importing a SUSE distribution
* Mon Apr  4 2011 ug@suse.de
- fixed the start of cobblerd when [tftpd] section is missing
  in the modules.conf
* Mon Apr  4 2011 ug@suse.de
- version from 2.0.10 to 2.1.0
* Wed Mar 23 2011 ug@suse.de
- changed logfiles to root:root (bnc#678433)
* Tue Mar 22 2011 ug@suse.de
- changed permissions in /var/log/ to root:www (bnc#678433)
* Fri Mar  4 2011 ug@suse.de
- patches cleaned up
* Mon Feb 28 2011 ug@suse.de
- fixed a crash because xml.dom.ext is not available on 11.4
* Thu Feb 17 2011 ug@suse.de
- fixed the restarting of services on SUSE
* Thu Feb 17 2011 ug@suse.de
- missing rc-script link added
* Wed Feb 16 2011 ug@suse.de
- don't add "#raw" comment per default anymore
* Wed Feb 16 2011 ug@suse.de
- cobbler failed to export kickstart profiles with $SNIPPET(...)
  cheetah_class_fix.diff added for that
* Tue Feb  8 2011 ug@suse.de
- removed grubby from the requires
* Thu Feb  3 2011 ug@suse.de
- packaged the cobbler.conf instead of cobbler_wsgi.conf
  (bnc#668968)
* Wed Feb  2 2011 ug@suse.de
- spec file fixed
* Fri Jan 28 2011 ug@suse.de
- fixed apache config to avoid warning
* Wed Jan 19 2011 ug@suse.de
- added firewall config
* Thu Jan 13 2011 ug@suse.de
- version update to 2.0.10
* Wed Jan 12 2011 ug@suse.de
- some template files were not packaged
* Tue Jan 11 2011 ug@suse.de
- removed xinetd from start script
* Tue Jan 11 2011 ug@suse.de
- update to version 2.0.8
